You can search for identifiers within the package.
in-package search v0.2.0
zipc
Zipc_deflate.Adler_32
Adler-32 checksums.
type t = uint32
The type for Adler-32 checksums.
val equal : t -> t -> bool
equal c0 c1 is true iff c0 and c1 are equal.
equal c0 c1
true
c0
c1
val check : expect:t -> found:t -> (unit, string) result
check ~expect ~found is Ok () iff equal exp found is true otherwise it errors with a human error message that mentions the checksums.
check ~expect ~found
Ok ()
equal exp found
val pp : Format.formatter -> t -> unit
pp formats a checksum.
pp
val string : ?start:int -> ?len:int -> string -> t
string s is the Adler-32 checksum of s in the range [start;start+len-1]. start defaults to 0 and length defaults to String.length b - start.
string s
s
start
start+len-1
0
length
String.length b - start