Page
Library
Module
Module type
Parameter
Class
Class type
Zipc.MemberSourceArchive members.
The type for archive member kinds.
The type for archive members.
make ~path kind creates a member for path of kind kind.
path goes through Fpath.ensure_unix and, if the member is a directory, Fpath.ensure_directoryness. Note that when you add the resulting member to an archive you may not be able to find it with the given path, you need to use the path of the result.mtime defaults to Ptime.dos_epoch. ZIP archives use MS-DOS date time whose epoch is on Ptime.dos_epoch anything before is truncated to itmode defaults 0o755 for directory entries and 0o644 for files.Error _ is returned with a suitable error message if the length of path exceeds max_path_length.
path m is the file path of m.
WARNING do not use this path on a file system without sanitizing it. Also, it may be the empty string.
mode m is the UNIX file mode of m.
pp_member formats members a bit like ls -l does. The reported byte size is the File.decompressed_size.
pp_long is like pp but adds more information.
max is 65535, the maximum number of members that can be encoded in a (non-ZIP64) ZIP archive.
max_path_length is 65535, the maximal size for member paths in ZIP archives.